@@ -23,8 +23,10 @@
 #include "celluloid-common.h"
 #include "celluloid-def.h"
 
+#include <adwaita.h>
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
+#include <glib/gi18n.h>
 #include <glib-object.h>
 #include <math.h>
 
@@ -42,10 +44,11 @@ enum
 struct _CelluloidVideoArea
 {
 	GtkBox parent_instance;
+	GtkWidget *toast_overlay;
 	GtkWidget *overlay;
 	GtkWidget *stack;
-	GtkWidget *draw_area;
 	GtkWidget *gl_area;
+	GtkWidget *initial_page;
 	GtkWidget *control_box;
 	GtkWidget *header_bar;
 	GtkWidget *control_box_revealer;
@@ -492,10 +495,11 @@ celluloid_video_area_class_init(CelluloidVideoAreaClass *klass)
 static void
 celluloid_video_area_init(CelluloidVideoArea *area)
 {
+	area->toast_overlay = adw_toast_overlay_new();
 	area->overlay = gtk_overlay_new();
 	area->stack = gtk_stack_new();
-	area->draw_area = gtk_drawing_area_new();
 	area->gl_area = gtk_gl_area_new();
+	area->initial_page = adw_status_page_new();
 	area->control_box = celluloid_control_box_new();
 	area->header_bar = celluloid_header_bar_new();
 	area->control_box_revealer = gtk_revealer_new();
@@ -596,10 +600,6 @@ celluloid_video_area_init(CelluloidVideoArea *area)
 				"resize",
 				G_CALLBACK(resize_handler),
 				area );
-	g_signal_connect(	area->draw_area,
-				"resize",
-				G_CALLBACK(resize_handler),
-				area );
 	g_signal_connect(	area->control_box,
 				"notify::volume-popup-visible",
 				G_CALLBACK(popover_notify_handler),
@@ -621,9 +621,19 @@ celluloid_video_area_init(CelluloidVideoArea *area)
 				G_CALLBACK(reveal_notify_handler),
 				area );
 
-	gtk_stack_add_named(GTK_STACK(area->stack), area->draw_area, "draw");
-	gtk_stack_add_named(GTK_STACK(area->stack), area->gl_area, "gl");
-	gtk_stack_set_visible_child(GTK_STACK(area->stack), area->draw_area);
+	adw_status_page_set_icon_name
+		(	ADW_STATUS_PAGE(area->initial_page),
+			"io.github.celluloid_player.Celluloid" );
+	adw_status_page_set_title
+		(	ADW_STATUS_PAGE(area->initial_page),
+			_("Welcome") );
+	adw_status_page_set_description
+		(	ADW_STATUS_PAGE(area->initial_page),
+			_("Press ＋ or drag your video file here.") );
+
+	gtk_stack_add_child(GTK_STACK(area->stack), area->gl_area);
+	gtk_stack_add_child(GTK_STACK(area->stack), area->initial_page);
+	gtk_stack_set_visible_child(GTK_STACK(area->stack), area->initial_page);
 
 	gtk_widget_set_hexpand(area->stack, TRUE);
 
@@ -641,7 +651,10 @@ celluloid_video_area_init(CelluloidVideoArea *area)
 	gtk_overlay_set_child
 		(GTK_OVERLAY(area->overlay), area->stack);
 
-	gtk_box_append(GTK_BOX(area), area->overlay);
+	adw_toast_overlay_set_child
+		(ADW_TOAST_OVERLAY(area->toast_overlay), area->overlay);
+	gtk_box_append
+		(GTK_BOX(area), area->toast_overlay);
 
 	celluloid_control_box_set_floating
 		(CELLULOID_CONTROL_BOX (area->control_box), TRUE);
@@ -669,6 +682,16 @@ celluloid_video_area_update_disc_list(	CelluloidVideoArea *area,
 		(CELLULOID_HEADER_BAR(area->header_bar), disc_list);
 }
 
+void
+celluloid_video_area_show_toast_message(	CelluloidVideoArea *area,
+						const gchar *msg)
+{
+	AdwToast *toast = adw_toast_new(msg);
+	AdwToastOverlay *toast_overlay = ADW_TOAST_OVERLAY(area->toast_overlay);
+
+	adw_toast_overlay_add_toast(toast_overlay, toast);
+}
+
 void
 celluloid_video_area_set_reveal_control_box(	CelluloidVideoArea *area,
 						gboolean reveal )
@@ -695,33 +718,27 @@ celluloid_video_area_set_control_box_visible(	CelluloidVideoArea *area,
 	gtk_widget_set_visible(area->control_box_revealer, visible);
 }
 
+void
+celluloid_video_area_set_initial_page_visible(	CelluloidVideoArea *area,
+						gboolean visible )
+{
+	GtkWidget *child = visible ? area->initial_page : area->gl_area;
+
+	gtk_stack_set_visible_child(GTK_STACK(area->stack), child);
+}
+
 gboolean
 celluloid_video_area_get_control_box_visible(CelluloidVideoArea *area)
 {
 	return gtk_widget_get_visible(area->control_box_revealer);
 }
 
-void
-celluloid_video_area_set_use_opengl(	CelluloidVideoArea *area,
-					gboolean use_opengl )
-{
-	gtk_stack_set_visible_child
-		(	GTK_STACK(area->stack),
-			use_opengl?area->gl_area:area->draw_area );
-}
-
 void
 celluloid_video_area_queue_render(CelluloidVideoArea *area)
 {
 	gtk_gl_area_queue_render(GTK_GL_AREA(area->gl_area));
 }
 
-GtkDrawingArea *
-celluloid_video_area_get_draw_area(CelluloidVideoArea *area)
-{
-	return GTK_DRAWING_AREA(area->draw_area);
-}
-
 GtkGLArea *
 celluloid_video_area_get_gl_area(CelluloidVideoArea *area)
 {
@@ -749,9 +766,9 @@ celluloid_video_area_get_xid(CelluloidVideoArea *area)
 		GtkWidget *parent = gtk_widget_get_parent(GTK_WIDGET(area));
 		GdkSurface *surface = NULL;
 
-		if(parent && !gtk_widget_get_realized(area->draw_area))
+		if(parent && !gtk_widget_get_realized(area->gl_area))
 		{
-			gtk_widget_realize(area->draw_area);
+			gtk_widget_realize(area->gl_area);
 		}
 
 		surface = gtk_widget_get_surface(area);
